[Pkg-mozext-commits] [requestpolicy] 248/280: [refact] rename helper addon to "RPC Dev Helper"

David Prévot taffit at moszumanska.debian.org
Sat May 2 20:30:35 UTC 2015


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository requestpolicy.

commit d63fbe2ab3799a3de60b1e420b939558924da377
Author: Martin Kimmerle <dev at 256k.de>
Date:   Tue Apr 28 08:44:43 2015 +0200

    [refact] rename helper addon to "RPC Dev Helper"
    
    rename the helper addon, formerly "RequestPolicy Observer", to
    "RPC Dev Helper"
---
 Makefile                                           | 40 +++++++++++-----------
 tests/mozmill/extension/bootstrap.js               |  6 ++--
 tests/mozmill/extension/chrome.manifest            |  2 +-
 .../mozmill/extension/content/console-observer.jsm |  2 +-
 .../extension/content/restart-detection-helper.jsm |  2 +-
 tests/mozmill/extension/install.rdf                |  4 +--
 .../initDetectingRestarts.js                       |  2 +-
 .../testAssertNoRestart.js                         |  2 +-
 .../testDetectingRestarts.js                       |  2 +-
 .../detectErrors/testAssertNoErrors.js             |  2 +-
 10 files changed, 32 insertions(+), 32 deletions(-)

diff --git a/Makefile b/Makefile
index 6cab305..02e59ef 100644
--- a/Makefile
+++ b/Makefile
@@ -118,18 +118,18 @@ unit_testing__empty_dirs := $(shell find $(unit_testing__build_path) -mindepth 1
 endif
 
 
-# ____________________________________
-# vars for generating the Observer XPI
+# ______________________________________
+# vars for generating the Dev Helper XPI
 #
 
-rp_observer__source_dirname := tests/mozmill/extension
-rp_observer__source_path := $(rp_observer__source_dirname)/
+dev_helper__source_dirname := tests/mozmill/extension
+dev_helper__source_path := $(dev_helper__source_dirname)/
 
-rp_observer__source_files := $(shell find $(rp_observer__source_dirname) -type f -regex ".*\.jsm?") \
-		$(rp_observer__source_dirname)/chrome.manifest \
-		$(rp_observer__source_dirname)/install.rdf
+dev_helper__source_files := $(shell find $(dev_helper__source_dirname) -type f -regex ".*\.jsm?") \
+		$(dev_helper__source_dirname)/chrome.manifest \
+		$(dev_helper__source_dirname)/install.rdf
 
-rp_observer__xpi_file := $(dist_path)$(extension_name)-observer.xpi
+dev_helper__xpi_file := $(dist_path)rpc-dev-helper.xpi
 
 
 # ______________________________
@@ -224,19 +224,19 @@ $(unit_testing__xpi_file): $(unit_testing__build_path) $(unit_testing__all_files
 	@echo "Creating unit-testing XPI: Done!"
 
 
-# _______________________
-# create the Observer XPI
+# _________________________
+# create the Dev Helper XPI
 #
 
 # For now use FORCE, i.e. create the XPI every time. If the
 # 'FORCE' should be removed, deleted files have to be detected,
 # just like for the other XPIs.
-$(rp_observer__xpi_file): $(rp_observer__source_files) FORCE | $(dist_path)
-	@rm -f $(rp_observer__xpi_file)
-	@echo "Creating Observer XPI."
-	@cd $(rp_observer__source_dirname) && \
-	$(ZIP) $(abspath $(rp_observer__xpi_file)) $(patsubst $(rp_observer__source_path)%,%,$(rp_observer__source_files))
-	@echo "Creating Observer XPI: Done!"
+$(dev_helper__xpi_file): $(dev_helper__source_files) FORCE | $(dist_path)
+	@rm -f $(dev_helper__xpi_file)
+	@echo "Creating 'RPC Dev Helper' XPI."
+	@cd $(dev_helper__source_dirname) && \
+	$(ZIP) $(abspath $(dev_helper__xpi_file)) $(patsubst $(dev_helper__source_path)%,%,$(dev_helper__source_files))
+	@echo "Creating 'RPC Dev Helper' XPI: Done!"
 
 # _____________________________________
 # create the files for the "normal" XPI
@@ -315,13 +315,13 @@ $(deleted_files): FORCE
 #
 
 # arguments for mozrunner
-mozrunner_args := -a $(moz_xpi) -a $(rp_observer__xpi_file)
+mozrunner_args := -a $(moz_xpi) -a $(dev_helper__xpi_file)
 mozrunner_args += -b $(app_binary)
 mozrunner_args += --preferences=$(mozrunner_prefs_ini):dev
 mozrunner_args += $(moz_args)
 
 .PHONY: run
-run: $(moz_xpi) $(rp_observer__xpi_file)
+run: $(moz_xpi) $(dev_helper__xpi_file)
 	mozrunner $(mozrunner_args)
 
 
@@ -341,8 +341,8 @@ mm_manifest := manifest.ini
 .PHONY: check test mozmill
 check test: mozmill
 
-mozmill: $(moz_xpi) $(rp_observer__xpi_file) mozmill-dirs
-	mozmill -a $(moz_xpi) -a $(rp_observer__xpi_file) -b $(app_binary) \
+mozmill: $(moz_xpi) $(dev_helper__xpi_file) mozmill-dirs
+	mozmill -a $(moz_xpi) -a $(dev_helper__xpi_file) -b $(app_binary) \
 		-m $(mozmill_requestpolicy_test_dir)/$(mm_manifest) $(moz_args)
 
 
diff --git a/tests/mozmill/extension/chrome.manifest b/tests/mozmill/extension/chrome.manifest
index bf67647..05b615f 100644
--- a/tests/mozmill/extension/chrome.manifest
+++ b/tests/mozmill/extension/chrome.manifest
@@ -1 +1 @@
-content    rp-observer    content/
+content    rpc-dev-helper    content/
diff --git a/tests/mozmill/extension/content/console-observer.jsm b/tests/mozmill/extension/content/console-observer.jsm
index 20a30cf..e87d2fd 100644
--- a/tests/mozmill/extension/content/console-observer.jsm
+++ b/tests/mozmill/extension/content/console-observer.jsm
@@ -1,7 +1,7 @@
 /*
  * ***** BEGIN LICENSE BLOCK *****
  *
- * RequestPolicy Observer - A helper add-on for RequestPolicy development.
+ * RPC Dev Helper - A helper add-on for RequestPolicy development.
  * Copyright (c) 2015 Martin Kimmerle
  *
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/tests/mozmill/extension/content/restart-detection-helper.jsm b/tests/mozmill/extension/content/restart-detection-helper.jsm
index c960b28..b1c91df 100644
--- a/tests/mozmill/extension/content/restart-detection-helper.jsm
+++ b/tests/mozmill/extension/content/restart-detection-helper.jsm
@@ -1,7 +1,7 @@
 /*
  * ***** BEGIN LICENSE BLOCK *****
  *
- * RequestPolicy Observer - A helper add-on for RequestPolicy development.
+ * RPC Dev Helper - A helper add-on for RequestPolicy development.
  * Copyright (c) 2015 Martin Kimmerle
  *
  * This program is free software: you can redistribute it and/or modify it under
diff --git a/tests/mozmill/extension/install.rdf b/tests/mozmill/extension/install.rdf
index 5a99b8d..7a07b43 100644
--- a/tests/mozmill/extension/install.rdf
+++ b/tests/mozmill/extension/install.rdf
@@ -4,11 +4,11 @@
   xmlns:em="http://www.mozilla.org/2004/em-rdf#">
 
   <Description about="urn:mozilla:install-manifest">
-    <em:name>RequestPolicy Observer</em:name>
+    <em:name>RPC Dev Helper</em:name>
     <em:version>dev</em:version>
     <em:type>2</em:type>
     <em:description>Helper Add-On for testing and developing RequestPolicy.</em:description>
-    <em:id>observer at requestpolicy.com</em:id>
+    <em:id>rpc-dev-helper at requestpolicy.org</em:id>
 
     <em:unpack>false</em:unpack>
     <em:bootstrap>true</em:bootstrap>
diff --git a/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/initDetectingRestarts.js b/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/initDetectingRestarts.js
index 5a7cb1f..fd5bf5e 100644
--- a/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/initDetectingRestarts.js
+++ b/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/initDetectingRestarts.js
@@ -4,7 +4,7 @@
 
 "use strict";
 
-Components.utils.import("chrome://rp-observer/content/restart-detection-helper.jsm");
+Components.utils.import("chrome://rpc-dev-helper/content/restart-detection-helper.jsm");
 
 
 function setupModule(aModule) {
diff --git a/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testAssertNoRestart.js b/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testAssertNoRestart.js
index 4f58dda..2dfd2f6 100644
--- a/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testAssertNoRestart.js
+++ b/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testAssertNoRestart.js
@@ -4,7 +4,7 @@
 
 "use strict";
 
-Components.utils.import("chrome://rp-observer/content/restart-detection-helper.jsm");
+Components.utils.import("chrome://rpc-dev-helper/content/restart-detection-helper.jsm");
 
 
 function setupModule(aModule) {
diff --git a/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testDetectingRestarts.js b/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testDetectingRestarts.js
index 3eda91d..f47f39f 100644
--- a/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testDetectingRestarts.js
+++ b/tests/mozmill/highLevelTests/repeatedTests/detectApplicationRestarts/testDetectingRestarts.js
@@ -4,7 +4,7 @@
 
 "use strict";
 
-Components.utils.import("chrome://rp-observer/content/restart-detection-helper.jsm");
+Components.utils.import("chrome://rpc-dev-helper/content/restart-detection-helper.jsm");
 
 
 function setupModule(aModule) {
diff --git a/tests/mozmill/highLevelTests/repeatedTests/detectErrors/testAssertNoErrors.js b/tests/mozmill/highLevelTests/repeatedTests/detectErrors/testAssertNoErrors.js
index 323759b..447044a 100644
--- a/tests/mozmill/highLevelTests/repeatedTests/detectErrors/testAssertNoErrors.js
+++ b/tests/mozmill/highLevelTests/repeatedTests/detectErrors/testAssertNoErrors.js
@@ -11,7 +11,7 @@ var rootDir = rpRootDir + rpConst.mozmillTestsRootDir;
 var {assert, expect} = require(rootDir + "lib/assertions");
 var prefs = require(rootDir + "lib/prefs");
 
-Components.utils.import("chrome://rp-observer/content/console-observer.jsm");
+Components.utils.import("chrome://rpc-dev-helper/content/console-observer.jsm");
 
 
 

diff --git a/tests/mozmill/extension/bootstrap.js b/tests/mozmill/extension/bootstrap.js
index 500dc01..2d1270c 100644
--- a/tests/mozmill/extension/bootstrap.js
+++ b/tests/mozmill/extension/bootstrap.js
@@ -1,7 +1,7 @@
 /*
  * ***** BEGIN LICENSE BLOCK *****
  *
  * RequestPolicy Observer - A helper add-on for RequestPolicy development.
  * Copyright (c) 2015 Martin Kimmerle
  *
  * This program is free software: you can redistribute it and/or modify it under
@@ -26,13 +26,13 @@ const Cu = Components.utils;
 
 
 function startup(data, reason) {
-  Cu.import("chrome://rp-observer/content/console-observer.jsm");
+  Cu.import("chrome://rpc-dev-helper/content/console-observer.jsm");
   ConsoleObserver.startup();
 }
 
 function shutdown(data, reason) {
   ConsoleObserver.shutdown();
-  Cu.unload("chrome://rp-observer/content/console-observer.jsm");
+  Cu.unload("chrome://rpc-dev-helper/content/console-observer.jsm");
 }
 
 function install(data, reason) {
@@ -1,7 +1,7 @@
  * ***** BEGIN LICENSE BLOCK *****
  *
- * RequestPolicy Observer - A helper add-on for RequestPolicy development.
+ * RPC Dev Helper - A helper add-on for RequestPolicy development.
  * Copyright (c) 2015 Martin Kimmerle
  *
-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/requestpolicy.git



More information about the Pkg-mozext-commits mailing list